# -*- coding: utf-8 -*-

import os

"""Event Loop is managed here"""
"""From telehash v2
https://github.com/telehash/plinth/blob/master/plinth/core.py

import gevent
from gevent.server import DatagramServer

from .log import log
from .identity import SwitchID
from . import packet
from . import crypto
from .dht import DHT
from .exceptions import *
"""

class Node(object):
    pass
